@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <stdlib.h>
 #include <string.h>
@@ -41,7 +41,7 @@ CTX::CTX() : debugSurface(-1), gamepad(0)
     homeDir += "/";
 
   batch = batchAfterMesh = 0;
-  meshDiscrete = 0;
+  batchSomeValue = 0;
   outputFileName = "";
   bgmFileName = "";
   createAppendMeshStatReport = 0;
