@@ -1,12 +1,12 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributed by Gilles Marckmann <gilles.marckmann@ec-nantes.fr>
 
-#ifndef _GAMEPAD_H_
-#define _GAMEPAD_H_
+#ifndef GAMEPAD_H
+#define GAMEPAD_H
 
 #define GP_RANGE 1.0
 #define GP_DEV 16
