@@ -207,8 +207,11 @@ void Msg::SetLogFile(const std::string &name)
 {
   _logFileName = name;
   if(_logFile) fclose(_logFile);
-  if(name.size())
+  if(name.size()){
     _logFile = Fopen(name.c_str(), "w");
+    if(!_logFile)
+      Msg::Error("Could not open file '%s'", name.c_str());
+  }
   else
     _logFile = 0;
 }
@@ -671,9 +674,9 @@ void Msg::Auto(const char *fmt, ...)
   va_start(args, fmt);
   vsnprintf(str, sizeof(str), fmt, args);
   va_end(args);
-  if(strstr(str, "Error") || strstr(str, "error"))
+  if(strstr(str, "Error") || strstr(str, "error") || strstr(str, "ERROR"))
     Msg::Error("%s", str);
-  else if(strstr(str, "Warning") || strstr(str, "warning"))
+  else if(strstr(str, "Warning") || strstr(str, "warning") || strstr(str, "WARNING"))
     Msg::Warning("%s", str);
   else
     Msg::Info("%s", str);
